@@ -319,6 +319,7 @@ def test_get_trip_observations_export():
                 target_date + timedelta(days=1),
                 target_date + timedelta(days=2),
             ],
+            routes=["5561911", "5561915"],
         )
         assert (
             df[df["tripId"] == "t_5561911_b_80157_tn_0"].iloc[0].scheduleRelationship
@@ -334,6 +335,7 @@ def test_get_trip_observations_export():
     assert sent_req.querystring["endDate"] == ["06-30-2023"]
     assert sent_req.querystring["daysOfWeek"] == ["1,2,3,4,6,7"]
     assert sent_req.querystring["excludeDates"] == ["07-01-2023,07-02-2023"]
+    assert sent_req.querystring["routes"] == ["5561911,5561915"]
 
 
 @httpretty.activate
